from termcolor import colored
class about: 
    def inita():
        text = colored("This package made by:\nR KIRAN KUMAR REDDY\n22CSEAIML010\nGIETU (GUNPUR)", 'red', attrs=['reverse', 'blink'])
        print(text)


from setuptools import setup, find_packages

setup(
    name='mlintern010',
    version='0.1.8',
    packages=find_packages(),
    author='R Kiran Kumar Reddy',
    author_email='rkirankumarreddy599@gmail.com',
    description='This is a package for data preprocessing',
    install_requires =[
        'numpy',
        'pandas',
        'termcolor'
    ],
    entry_points={
        'console_scripts': ['mlintern-010=mlintern010:inita'],
    },
)